==> org.eclipse.php.debug.ui.source_4.3.1.201703301037.jar: org/eclipse/php/internal/debug/ui/pathmapper/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
package org.eclipse.php.internal.debug.ui.pathmapper;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.php.internal.debug.ui.pathmapper.messages"; //$NON-NLS-1$
	public static String OpenLocalFileSearchFilter_External_files;
	public static String OpenLocalFileSearchFilter_Open_file_request;
	public static String OpenLocalFileSearchFilter_Select_the_local_resource_match;
	public static String PathEntrySelectionDialog_0;
	public static String PathEntrySelectionDialog_1;
	public static String PathEntrySelectionDialog_2;
	public static String PathEntrySelectionDialog_3;
	public static String PathEntrySelectionDialog_4;
	public static String PathEntrySelectionDialog_5;
	public static String PathEntrySelectionDialog_6;
	public static String PathMapperEntryDialog_0;
	public static String PathMapperEntryDialog_1;
	public static String PathMapperEntryDialog_10;
	public static String PathMapperEntryDialog_11;
	public static String PathMapperEntryDialog_12;
	public static String PathMapperEntryDialog_13;
	public static String PathMapperEntryDialog_14;
	public static String PathMapperEntryDialog_15;
	public static String PathMapperEntryDialog_16;
	public static String PathMapperEntryDialog_17;
	public static String PathMapperEntryDialog_18;
	public static String PathMapperEntryDialog_19;
	public static String PathMapperEntryDialog_2;
	public static String PathMapperEntryDialog_3;
	public static String PathMapperEntryDialog_4;
	public static String PathMapperEntryDialog_5;
	public static String PathMapperEntryDialog_6;
	public static String PathMapperEntryDialog_7;
	public static String PathMapperEntryDialog_8;
	public static String PathMapperEntryDialog_9;
	public static String PathMappingComposite_0;
	public static String PathMappingComposite_1;
	public static String PathMappingComposite_2;
	public static String PathMappingComposite_3;
	public static String PathMappingComposite_4;
	public static String PathMappingComposite_5;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.php.debug.ui.source_8.2.0.202311292129.jar: org/eclipse/php/internal/debug/ui/pathmapper/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
package org.eclipse.php.internal.debug.ui.pathmapper;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.php.internal.debug.ui.pathmapper.messages"; //$NON-NLS-1$
	public static String OpenLocalFileSearchFilter_External_files;
	public static String OpenLocalFileSearchFilter_Open_file_request;
	public static String OpenLocalFileSearchFilter_Map_and_open_local;
	public static String OpenLocalFileSearchFilter_Open_remote;
	public static String OpenLocalFileSearchFilter_Remote_file_is_requested;
	public static String PathEntrySelectionDialog_0;
	public static String PathEntrySelectionDialog_1;
	public static String PathEntrySelectionDialog_2;
	public static String PathEntrySelectionDialog_3;
	public static String PathEntrySelectionDialog_4;
	public static String PathEntrySelectionDialog_5;
	public static String PathEntrySelectionDialog_6;
	public static String PathMapperEntryDialog_0;
	public static String PathMapperEntryDialog_1;
	public static String PathMapperEntryDialog_10;
	public static String PathMapperEntryDialog_11;
	public static String PathMapperEntryDialog_12;
	public static String PathMapperEntryDialog_13;
	public static String PathMapperEntryDialog_14;
	public static String PathMapperEntryDialog_15;
	public static String PathMapperEntryDialog_16;
	public static String PathMapperEntryDialog_17;
	public static String PathMapperEntryDialog_18;
	public static String PathMapperEntryDialog_19;
	public static String PathMapperEntryDialog_2;
	public static String PathMapperEntryDialog_3;
	public static String PathMapperEntryDialog_4;
	public static String PathMapperEntryDialog_5;
	public static String PathMapperEntryDialog_6;
	public static String PathMapperEntryDialog_7;
	public static String PathMapperEntryDialog_8;
	public static String PathMapperEntryDialog_9;
	public static String PathMappingComposite_0;
	public static String PathMappingComposite_1;
	public static String PathMappingComposite_2;
	public static String PathMappingComposite_3;
	public static String PathMappingComposite_4;
	public static String PathMappingComposite_5;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
